from typing import Literal
from pydantic import BaseModel
import requests

Role = Literal['user', 'assistant', 'system']

class MessageType(BaseModel):
    role: Role
    content: str

# class MessageType:
#     def __init__(self, role: str, content: str):
#         self.role = role
#         self.content = content

class BasicPayload:
    def __init__(self, mix_tuning_id: str, messages: list, temperature: float, max_tokens: int):
        self.mix_tuning_id = mix_tuning_id
        self.messages = messages
        self.temperature = temperature
        self.max_tokens = max_tokens

class BasicMoAi:
    def __init__(self, api_key: str):
        self.api_url = 'https://moai-service-app.humiris.ai/api/api-key-operators/use-basic-mixtuning'
        self.api_key = api_key

    def use_basic_mixtuning(self, payload: BasicPayload):
        headers = {
            'moai-api-key': self.api_key,
            'Content-Type': 'application/json'
        }

         # Convert payload and MessageType objects to dictionaries
        # Conversion correcte pour Pydantic v2
        payload_data = {
            "mix_tuning_id": payload.mix_tuning_id,
            "messages": [message.model_dump() for message in payload.messages],  # <-- Correction ici
            "temperature": payload.temperature,
            "max_tokens": payload.max_tokens
        }

        try:
            response = requests.post(self.api_url, json=payload_data, headers=headers)
            response.raise_for_status()
            return response.json()
        except requests.exceptions.RequestException as error:
            raise Exception(f"Failed to send request: {error}")




import requests

class MessageType:
    def __init__(self, role: str, content: str):
        self.role = role
        self.content = content

class AdvancedPayload:
    def __init__(self, advanced_mix_tuning_id: str, messages: list, temperature: float, max_tokens: int):
        self.advanced_mix_tuning_id = advanced_mix_tuning_id
        self.messages = messages
        self.temperature = temperature
        self.max_tokens = max_tokens

class AdvancedMoAi:
    def __init__(self, api_key: str):
        self.api_url = 'https://moai-service-app.humiris.ai/api/api-key-operators/use-advanced-mixtuning'
        self.api_key = api_key

    def use_advanced_mixtuning(self, payload: AdvancedPayload):
        headers = {
            'moai-api-key': self.api_key,
            'Content-Type': 'application/json'
        }
        try:
            response = requests.post(self.api_url, json=vars(payload), headers=headers)
            response.raise_for_status()
            return response.json()
        except requests.exceptions.RequestException as error:
            raise Exception(f"Failed to send request: {error}")




from setuptools import setup, find_packages

setup(
    name='humiris_ai',
    version='1.0.11',
    author='Hilario Houmey',
    author_email='h.hilario@humiris.ai',
    description='Humiris AI is a library that allows developers to seamlessly integrate Mixture of AI Basic and Advanced into their applications.',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    url='https://github.com/joeai-tech-org/humiris-pip-package',
    packages=find_packages(),
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    python_requires='>=3.6',
    install_requires=[
        # list your package dependencies here
    "requests>=2.20.0",
    "setuptools>=40.0.0",
    "pydantic>=2.20.1"
    ],
)